@@ -21,6 +21,7 @@ import static org.apache.hugegraph.config.OptionChecker.allowValues;
 import static org.apache.hugegraph.config.OptionChecker.disallowEmpty;
 import static org.apache.hugegraph.config.OptionChecker.nonNegativeInt;
 import static org.apache.hugegraph.config.OptionChecker.positiveInt;
+import static org.apache.hugegraph.config.OptionChecker.rangeDouble;
 import static org.apache.hugegraph.config.OptionChecker.rangeInt;
 
 public class ServerOptions extends OptionHolder {
@@ -47,6 +48,14 @@ public class ServerOptions extends OptionHolder {
                     "http://127.0.0.1:8080"
             );
 
+    public static final ConfigOption<Boolean> REST_SERVER_ENABLE_GRAPHSPACES_FILTER =
+            new ConfigOption<>(
+                    "restserver.enable_graphspaces_filter",
+                    "Whether to enable graphspaces url filter.",
+                    disallowEmpty(),
+                    false
+            );
+
     public static final ConfigOption<String> SERVER_ID =
             new ConfigOption<>(
                     "server.id",
@@ -313,4 +322,22 @@ public class ServerOptions extends OptionHolder {
                     nonNegativeInt(),
                     1000L
             );
+
+    public static final ConfigOption<Double> JVM_MEMORY_MONITOR_THRESHOLD =
+            new ConfigOption<>(
+                    "memory_monitor.threshold",
+                    "Threshold for JVM memory usage monitoring, 1 means disabling the memory " +
+                    "monitoring task.",
+                    rangeDouble(0.0, 1.0),
+                    0.85
+            );
+
+    public static final ConfigOption<Integer> JVM_MEMORY_MONITOR_DETECT_PERIOD =
+            new ConfigOption<>(
+                    "memory_monitor.period",
+                    "The period in ms of JVM memory usage monitoring, in each period we will " +
+                    "detect the jvm memory usage and take corresponding actions.",
+                    nonNegativeInt(),
+                    2000
+            );
 }
