@@ -89,7 +89,7 @@ public final class GraphManager {
     private final RpcClientProvider rpcClient;
 
     private RoleElectionStateMachine roleStateMachine;
-    private GlobalMasterInfo globalNodeRoleInfo;
+    private final GlobalMasterInfo globalNodeRoleInfo;
 
     private final HugeConfig conf;
     private final EventHub eventHub;
@@ -265,7 +265,7 @@ public final class GraphManager {
         return this.authenticator().authenticate(credentials);
     }
 
-    public void unauthorize(SecurityContext context) {
+    public void unauthorized(SecurityContext context) {
         this.authenticator().unauthorize(context);
     }
 
@@ -401,17 +401,17 @@ public final class GraphManager {
     }
 
     private void transferRoleWorkerConfig(HugeConfig config) {
-        config.addProperty(RoleElectionOptions.NODE_EXTERNAL_URL.name(),
+        config.setProperty(RoleElectionOptions.NODE_EXTERNAL_URL.name(),
                            this.conf.get(ServerOptions.REST_SERVER_URL));
-        config.addProperty(RoleElectionOptions.BASE_TIMEOUT_MILLISECOND.name(),
+        config.setProperty(RoleElectionOptions.BASE_TIMEOUT_MILLISECOND.name(),
                            this.conf.get(RoleElectionOptions.BASE_TIMEOUT_MILLISECOND));
-        config.addProperty(RoleElectionOptions.EXCEEDS_FAIL_COUNT.name(),
+        config.setProperty(RoleElectionOptions.EXCEEDS_FAIL_COUNT.name(),
                            this.conf.get(RoleElectionOptions.EXCEEDS_FAIL_COUNT));
-        config.addProperty(RoleElectionOptions.RANDOM_TIMEOUT_MILLISECOND.name(),
+        config.setProperty(RoleElectionOptions.RANDOM_TIMEOUT_MILLISECOND.name(),
                            this.conf.get(RoleElectionOptions.RANDOM_TIMEOUT_MILLISECOND));
-        config.addProperty(RoleElectionOptions.HEARTBEAT_INTERVAL_SECOND.name(),
+        config.setProperty(RoleElectionOptions.HEARTBEAT_INTERVAL_SECOND.name(),
                            this.conf.get(RoleElectionOptions.HEARTBEAT_INTERVAL_SECOND));
-        config.addProperty(RoleElectionOptions.MASTER_DEAD_TIMES.name(),
+        config.setProperty(RoleElectionOptions.MASTER_DEAD_TIMES.name(),
                            this.conf.get(RoleElectionOptions.MASTER_DEAD_TIMES));
     }
 
@@ -515,7 +515,7 @@ public final class GraphManager {
 
     private void addMetrics(HugeConfig config) {
         final MetricManager metric = MetricManager.INSTANCE;
-        // Force to add server reporter
+        // Force to add a server reporter
         ServerReporter reporter = ServerReporter.instance(metric.getRegistry());
         reporter.start(60L, TimeUnit.SECONDS);
 
@@ -610,7 +610,7 @@ public final class GraphManager {
 
         /*
          * Will fill graph instance into HugeFactory.graphs after
-         * GraphFactory.open() succeed, remove it when graph drop
+         * GraphFactory.open() succeed, remove it when the graph drops
          */
         HugeFactory.remove(graph);
     }
