@@ -41,6 +41,7 @@ public class HugeTarget extends Entity {
 
     private String name;
     private String graph;
+    private String description;
     private String url;
     private List<HugeResource> resources;
 
@@ -91,6 +92,18 @@ public class HugeTarget extends Entity {
         return this.graph;
     }
 
+    public void graph(String graph) {
+        this.graph = graph;
+    }
+
+    public String description() {
+        return this.description;
+    }
+
+    public void description(String description) {
+        this.description = description;
+    }
+
     public String url() {
         return this.url;
     }
@@ -257,4 +270,9 @@ public class HugeTarget extends Entity {
             return super.initProperties(props);
         }
     }
+
+    public static HugeTarget fromMap(Map<String, Object> map) {
+        HugeTarget target = new HugeTarget(null);
+        return fromMap(map, target);
+    }
 }
