@@ -47,7 +47,8 @@ public abstract class Condition {
         NONE,
         RELATION,
         AND,
-        OR
+        OR,
+        NOT
     }
 
     public enum RelationType implements BiPredicate<Object, Object> {
@@ -300,7 +301,8 @@ public abstract class Condition {
 
     public boolean isLogic() {
         return this.type() == ConditionType.AND ||
-               this.type() == ConditionType.OR;
+               this.type() == ConditionType.OR ||
+               this.type() == ConditionType.NOT;
     }
 
     public boolean isFlattened() {
@@ -315,6 +317,10 @@ public abstract class Condition {
         return new Or(left, right);
     }
 
+    public static Condition not(Condition condition) {
+        return new Not(condition);
+    }
+
     public static Relation eq(HugeKeys key, Object value) {
         return new SyspropRelation(key, RelationType.EQ, value);
     }
@@ -536,6 +542,80 @@ public abstract class Condition {
         }
     }
 
+    public static class Not extends Condition {
+
+        Condition condition;
+
+        public Not(Condition condition) {
+            super();
+            this.condition = condition;
+        }
+
+        public Condition condition() {
+            return condition;
+        }
+
+        @Override
+        public ConditionType type() {
+            return ConditionType.NOT;
+        }
+
+        @Override
+        public boolean test(Object value) {
+            return !this.condition.test(value);
+        }
+
+        @Override
+        public boolean test(HugeElement element) {
+            return !this.condition.test(element);
+        }
+
+        @Override
+        public Condition copy() {
+            return new Not(this.condition.copy());
+        }
+
+        @Override
+        public boolean isSysprop() {
+            return this.condition.isSysprop();
+        }
+
+        @Override
+        public List<? extends Relation> relations() {
+            return new ArrayList<Relation>(this.condition.relations());
+        }
+
+        @Override
+        public Condition replace(Relation from, Relation to) {
+            this.condition = this.condition.replace(from, to);
+            return this;
+        }
+
+        @Override
+        public String toString() {
+            StringBuilder sb = new StringBuilder(64);
+            sb.append(this.type().name()).append(' ');
+            sb.append(this.condition);
+            return sb.toString();
+        }
+
+        @Override
+        public boolean equals(Object object) {
+            if (!(object instanceof Not)) {
+                return false;
+            }
+            Not other = (Not) object;
+            return this.type().equals(other.type()) &&
+                   this.condition.equals(other.condition());
+        }
+
+        @Override
+        public int hashCode() {
+            return this.type().hashCode() ^
+                   this.condition.hashCode();
+        }
+    }
+
     public abstract static class Relation extends Condition {
 
         // Relational operator (like: =, >, <, in, ...)
