@@ -62,12 +62,15 @@ public class Query implements Cloneable {
     private long actualOffset;
     private long actualStoreOffset;
     private long limit;
+    private long skipDegree;
     private String page;
     private long capacity;
     private boolean showHidden;
     private boolean showDeleting;
     private boolean showExpired;
     private boolean olap;
+    private boolean withProperties;
+    private OrderType orderType;
     private Set<Id> olapPks;
 
     private Aggregate aggregate;
@@ -88,6 +91,7 @@ public class Query implements Cloneable {
         this.actualOffset = 0L;
         this.actualStoreOffset = 0L;
         this.limit = NO_LIMIT;
+        this.skipDegree = NO_LIMIT;
         this.page = null;
 
         this.capacity = defaultCapacity();
@@ -95,6 +99,9 @@ public class Query implements Cloneable {
         this.showHidden = false;
         this.showDeleting = false;
 
+        this.withProperties = true;
+        this.orderType = OrderType.ORDER_STRICT;
+
         this.aggregate = null;
         this.showExpired = false;
         this.olap = false;
@@ -105,10 +112,13 @@ public class Query implements Cloneable {
         E.checkNotNull(query, "query");
         this.offset = query.offset();
         this.limit = query.limit();
+        this.skipDegree = query.skipDegree();
         this.page = query.page();
         this.capacity = query.capacity();
         this.showHidden = query.showHidden();
         this.showDeleting = query.showDeleting();
+        this.withProperties = query.withProperties();
+        this.orderType = query.orderType();
         this.aggregate = query.aggregate();
         this.showExpired = query.showExpired();
         this.olap = query.olap();
@@ -129,6 +139,10 @@ public class Query implements Cloneable {
         return this.originQuery;
     }
 
+    public void setOriginQuery(Query query) {
+        this.originQuery = query;
+    }
+
     public Query rootOriginQuery() {
         Query root = this;
         while (root.originQuery != null) {
@@ -441,6 +455,30 @@ public class Query implements Cloneable {
         this.showDeleting = showDeleting;
     }
 
+    public long skipDegree() {
+        return this.skipDegree;
+    }
+
+    public void skipDegree(long skipDegree) {
+        this.skipDegree = skipDegree;
+    }
+
+    public boolean withProperties() {
+        return this.withProperties;
+    }
+
+    public void withProperties(boolean withProperties) {
+        this.withProperties = withProperties;
+    }
+
+    public OrderType orderType() {
+        return this.orderType;
+    }
+
+    public void orderType(OrderType orderType) {
+        this.orderType = orderType;
+    }
+
     public boolean showExpired() {
         return this.showExpired;
     }
@@ -493,7 +531,8 @@ public class Query implements Cloneable {
                this.limit == other.limit &&
                Objects.equals(this.page, other.page) &&
                this.ids().equals(other.ids()) &&
-               this.conditions().equals(other.conditions());
+               this.conditions().equals(other.conditions()) &&
+               this.withProperties == other.withProperties;
     }
 
     @Override
@@ -504,7 +543,8 @@ public class Query implements Cloneable {
                Long.hashCode(this.limit) ^
                Objects.hashCode(this.page) ^
                this.ids().hashCode() ^
-               this.conditions().hashCode();
+               this.conditions().hashCode() ^
+               Boolean.hashCode(this.withProperties);
     }
 
     @Override
@@ -580,6 +620,13 @@ public class Query implements Cloneable {
         }
     }
 
+    public enum OrderType {
+        // Under batch interface, the requirement for return order
+        ORDER_NONE,           // Allow unordered
+        ORDER_WITHIN_VERTEX,  // Edges within a vertex will not be broken, but there is no order between different vertices.
+        ORDER_STRICT          // Ensure the original input point order
+    }
+
     public enum Order {
         ASC,
         DESC
