@@ -23,6 +23,7 @@ import java.util.function.Function;
 import org.apache.hugegraph.HugeGraph;
 import org.apache.hugegraph.backend.id.Id;
 import org.apache.hugegraph.backend.id.IdGenerator;
+import org.apache.hugegraph.backend.tx.ISchemaTransaction;
 import org.apache.hugegraph.backend.tx.SchemaTransaction;
 import org.apache.hugegraph.exception.ExistedException;
 import org.apache.hugegraph.schema.EdgeLabel;
@@ -38,10 +39,10 @@ import org.apache.hugegraph.util.LockUtil;
 
 public abstract class AbstractBuilder {
 
-    private final SchemaTransaction transaction;
+    private final ISchemaTransaction transaction;
     private final HugeGraph graph;
 
-    public AbstractBuilder(SchemaTransaction transaction, HugeGraph graph) {
+    public AbstractBuilder(ISchemaTransaction transaction, HugeGraph graph) {
         E.checkNotNull(transaction, "transaction");
         E.checkNotNull(graph, "graph");
         this.transaction = transaction;
