@@ -38,28 +38,22 @@ import org.apache.hugegraph.backend.query.Condition;
 import org.apache.hugegraph.backend.query.ConditionQuery;
 import org.apache.hugegraph.backend.query.QueryResults;
 import org.apache.hugegraph.backend.store.BackendStore;
-import org.apache.hugegraph.backend.tx.GraphTransaction;
 import org.apache.hugegraph.config.CoreOptions;
 import org.apache.hugegraph.exception.ConnectionException;
 import org.apache.hugegraph.exception.NotFoundException;
 import org.apache.hugegraph.iterator.ExtendableIterator;
 import org.apache.hugegraph.iterator.MapperIterator;
 import org.apache.hugegraph.job.EphemeralJob;
-import org.apache.hugegraph.schema.IndexLabel;
 import org.apache.hugegraph.schema.PropertyKey;
-import org.apache.hugegraph.schema.SchemaManager;
 import org.apache.hugegraph.schema.VertexLabel;
 import org.apache.hugegraph.structure.HugeVertex;
 import org.apache.hugegraph.task.HugeTask.P;
 import org.apache.hugegraph.task.TaskCallable.SysTaskCallable;
 import org.apache.hugegraph.task.TaskManager.ContextCallable;
 import org.apache.hugegraph.type.HugeType;
-import org.apache.hugegraph.type.define.Cardinality;
-import org.apache.hugegraph.type.define.DataType;
 import org.apache.hugegraph.type.define.HugeKeys;
 import org.apache.hugegraph.util.E;
 import org.apache.hugegraph.util.Log;
-import org.apache.tinkerpop.gremlin.structure.Graph.Hidden;
 import org.apache.tinkerpop.gremlin.structure.Vertex;
 import org.slf4j.Logger;
 
@@ -79,11 +73,6 @@ public class StandardTaskScheduler implements TaskScheduler {
 
     private volatile TaskTransaction taskTx;
 
-    private static final long NO_LIMIT = -1L;
-    private static final long PAGE_SIZE = 500L;
-    private static final long QUERY_INTERVAL = 100L;
-    private static final int MAX_PENDING_TASKS = 10000;
-
     public StandardTaskScheduler(HugeGraphParams graph,
                                  ExecutorService taskExecutor,
                                  ExecutorService taskDbExecutor,
@@ -107,6 +96,7 @@ public class StandardTaskScheduler implements TaskScheduler {
         return this.graph.graph();
     }
 
+    @Override
     public String graphName() {
         return this.graph.name();
     }
@@ -130,7 +120,7 @@ public class StandardTaskScheduler implements TaskScheduler {
                 if (this.taskTx == null) {
                     BackendStore store = this.graph.loadSystemStore();
                     TaskTransaction tx = new TaskTransaction(this.graph, store);
-                    assert this.taskTx == null; // may be reentrant?
+                    assert this.taskTx == null; // maybe reentrant?
                     this.taskTx = tx;
                 }
             }
@@ -206,7 +196,7 @@ public class StandardTaskScheduler implements TaskScheduler {
 
         if (this.serverManager().onlySingleNode() && !task.computer()) {
             /*
-             * Speed up for single node, submit task immediately,
+             * Speed up for single node, submit the task immediately,
              * this code can be removed without affecting code logic
              */
             task.status(TaskStatus.QUEUED);
@@ -215,7 +205,7 @@ public class StandardTaskScheduler implements TaskScheduler {
             return this.submitTask(task);
         } else {
             /*
-             * Just set SCHEDULING status and save task,
+             * Just set the SCHEDULING status and save the task,
              * it will be scheduled by periodic scheduler worker
              */
             task.status(TaskStatus.SCHEDULING);
@@ -286,11 +276,11 @@ public class StandardTaskScheduler implements TaskScheduler {
             assert this.serverManager().selfIsMaster();
             if (!task.server().equals(this.serverManager().selfNodeId())) {
                 /*
-                 * Remove task from memory if it's running on worker node,
-                 * but keep task in memory if it's running on master node.
-                 * cancel-scheduling will read task from backend store, if
+                 * Remove the task from memory if it's running on worker node,
+                 * but keep the task in memory if it's running on master node.
+                 * Cancel-scheduling will read the task from backend store, if
                  * removed this instance from memory, there will be two task
-                 * instances with same id, and can't cancel the real task that
+                 * instances with the same id, and can't cancel the real task that
                  * is running but removed from memory.
                  */
                 this.remove(task);
@@ -304,18 +294,17 @@ public class StandardTaskScheduler implements TaskScheduler {
                                 task.id(), task.status());
     }
 
-    protected ServerInfoManager serverManager() {
+    @Override
+    public ServerInfoManager serverManager() {
         return this.serverManager;
     }
 
     protected synchronized void scheduleTasksOnMaster() {
         // Master server schedule all scheduling tasks to suitable worker nodes
-        Collection<HugeServerInfo> serverInfos = this.serverManager()
-                                                     .allServerInfos();
+        Collection<HugeServerInfo> serverInfos = this.serverManager().allServerInfos();
         String page = this.supportsPaging() ? PageInfo.PAGE_NONE : null;
         do {
-            Iterator<HugeTask<Object>> tasks = this.tasks(TaskStatus.SCHEDULING,
-                                                          PAGE_SIZE, page);
+            Iterator<HugeTask<Object>> tasks = this.tasks(TaskStatus.SCHEDULING, PAGE_SIZE, page);
             while (tasks.hasNext()) {
                 HugeTask<?> task = tasks.next();
                 if (task.server() != null) {
@@ -327,12 +316,10 @@ public class StandardTaskScheduler implements TaskScheduler {
                     return;
                 }
 
-                HugeServerInfo server = this.serverManager().pickWorkerNode(
-                        serverInfos, task);
+                HugeServerInfo server = this.serverManager().pickWorkerNode(serverInfos, task);
                 if (server == null) {
                     LOG.info("The master can't find suitable servers to " +
-                             "execute task '{}', wait for next schedule",
-                             task.id());
+                             "execute task '{}', wait for next schedule", task.id());
                     continue;
                 }
 
@@ -345,8 +332,7 @@ public class StandardTaskScheduler implements TaskScheduler {
                 // Update server load in memory, it will be saved at the ending
                 server.increaseLoad(task.load());
 
-                LOG.info("Scheduled task '{}' to server '{}'",
-                         task.id(), server.id());
+                LOG.info("Scheduled task '{}' to server '{}'", task.id(), server.id());
             }
             if (page != null) {
                 page = PageInfo.pageInfo(tasks);
@@ -360,8 +346,7 @@ public class StandardTaskScheduler implements TaskScheduler {
     protected void executeTasksOnWorker(Id server) {
         String page = this.supportsPaging() ? PageInfo.PAGE_NONE : null;
         do {
-            Iterator<HugeTask<Object>> tasks = this.tasks(TaskStatus.SCHEDULED,
-                                                          PAGE_SIZE, page);
+            Iterator<HugeTask<Object>> tasks = this.tasks(TaskStatus.SCHEDULED, PAGE_SIZE, page);
             while (tasks.hasNext()) {
                 HugeTask<?> task = tasks.next();
                 this.initTaskCallable(task);
@@ -390,8 +375,7 @@ public class StandardTaskScheduler implements TaskScheduler {
     protected void cancelTasksOnWorker(Id server) {
         String page = this.supportsPaging() ? PageInfo.PAGE_NONE : null;
         do {
-            Iterator<HugeTask<Object>> tasks = this.tasks(TaskStatus.CANCELLING,
-                                                          PAGE_SIZE, page);
+            Iterator<HugeTask<Object>> tasks = this.tasks(TaskStatus.CANCELLING, PAGE_SIZE, page);
             while (tasks.hasNext()) {
                 HugeTask<?> task = tasks.next();
                 Id taskServer = task.server();
@@ -425,7 +409,8 @@ public class StandardTaskScheduler implements TaskScheduler {
         } while (page != null);
     }
 
-    protected void taskDone(HugeTask<?> task) {
+    @Override
+    public void taskDone(HugeTask<?> task) {
         this.remove(task);
 
         Id selfServerId = this.serverManager().selfNodeId();
@@ -439,13 +424,17 @@ public class StandardTaskScheduler implements TaskScheduler {
     }
 
     protected void remove(HugeTask<?> task) {
+        this.remove(task, false);
+    }
+
+    protected void remove(HugeTask<?> task, boolean force) {
         E.checkNotNull(task, "remove task");
         HugeTask<?> delTask = this.tasks.remove(task.id());
         if (delTask != null && delTask != task) {
             LOG.warn("Task '{}' may be inconsistent status {}(expect {})",
                      task.id(), task.status(), delTask.status());
         }
-        assert delTask == null || delTask.completed() ||
+        assert force || delTask == null || delTask.completed() ||
                delTask.cancelling() || delTask.isCancelled() : delTask;
     }
 
@@ -528,8 +517,8 @@ public class StandardTaskScheduler implements TaskScheduler {
     }
 
     public <V> HugeTask<V> findTask(Id id) {
-        HugeTask<V> result = this.call(() -> {
-            Iterator<Vertex> vertices = this.tx().queryVertices(id);
+        HugeTask<V> result =  this.call(() -> {
+            Iterator<Vertex> vertices = this.tx().queryTaskInfos(id);
             Vertex vertex = QueryResults.one(vertices);
             if (vertex == null) {
                 return null;
@@ -556,36 +545,36 @@ public class StandardTaskScheduler implements TaskScheduler {
     }
 
     @Override
-    public <V> HugeTask<V> delete(Id id) {
+    public <V> HugeTask<V> delete(Id id, boolean force) {
         this.checkOnMasterNode("delete");
 
         HugeTask<?> task = this.task(id);
         /*
-         * The following is out of date when task running on worker node:
+         * The following is out of date when the task running on worker node:
          * HugeTask<?> task = this.tasks.get(id);
          * Tasks are removed from memory after completed at most time,
-         * but there is a tiny gap between tasks are completed and
+         * but there is a tiny gap between tasks is completed and
          * removed from memory.
          * We assume tasks only in memory may be incomplete status,
          * in fact, it is also possible to appear on the backend tasks
          * when the database status is inconsistent.
          */
         if (task != null) {
-            E.checkArgument(task.completed(),
+            E.checkArgument(force || task.completed(),
                             "Can't delete incomplete task '%s' in status %s" +
                             ", Please try to cancel the task first",
                             id, task.status());
-            this.remove(task);
+            this.remove(task, force);
         }
 
         return this.call(() -> {
-            Iterator<Vertex> vertices = this.tx().queryVertices(id);
+            Iterator<Vertex> vertices = this.tx().queryTaskInfos(id);
             HugeVertex vertex = (HugeVertex) QueryResults.one(vertices);
             if (vertex == null) {
                 return null;
             }
             HugeTask<V> result = HugeTask.fromVertex(vertex);
-            E.checkState(result.completed(),
+            E.checkState(force || result.completed(),
                          "Can't delete incomplete task '%s' in status %s",
                          id, result.status());
             this.tx().removeVertex(vertex);
@@ -625,7 +614,7 @@ public class StandardTaskScheduler implements TaskScheduler {
                 throw e;
             }
             if (task.completed()) {
-                // Wait for task result being set after status is completed
+                // Wait for the task result being set after the status is completed
                 sleep(intervalMs);
                 return task;
             }
@@ -672,7 +661,12 @@ public class StandardTaskScheduler implements TaskScheduler {
     private <V> Iterator<HugeTask<V>> queryTask(Map<String, Object> conditions,
                                                 long limit, String page) {
         return this.call(() -> {
-            ConditionQuery query = new ConditionQuery(HugeType.VERTEX);
+            ConditionQuery query;
+            if (this.graph.backendStoreFeatures().supportsTaskAndServerVertex()) {
+                query = new ConditionQuery(HugeType.TASK);
+            } else {
+                query = new ConditionQuery(HugeType.VERTEX);
+            }
             if (page != null) {
                 query.page(page);
             }
@@ -697,7 +691,7 @@ public class StandardTaskScheduler implements TaskScheduler {
     private <V> Iterator<HugeTask<V>> queryTask(List<Id> ids) {
         return this.call(() -> {
             Object[] idArray = ids.toArray(new Id[0]);
-            Iterator<Vertex> vertices = this.tx().queryVertices(idArray);
+            Iterator<Vertex> vertices = this.tx().queryTaskInfos(idArray);
             Iterator<HugeTask<V>> tasks =
                     new MapperIterator<>(vertices, HugeTask::fromVertex);
             // Convert iterator to list to avoid across thread tx accessed
@@ -705,11 +699,13 @@ public class StandardTaskScheduler implements TaskScheduler {
         });
     }
 
-    private <V> V call(Runnable runnable) {
+    @Override
+    public <V> V call(Runnable runnable) {
         return this.call(Executors.callable(runnable, null));
     }
 
-    private <V> V call(Callable<V> callable) {
+    @Override
+    public <V> V call(Callable<V> callable) {
         assert !Thread.currentThread().getName().startsWith(
                 "task-db-worker") : "can't call by itself";
         try {
@@ -742,129 +738,4 @@ public class StandardTaskScheduler implements TaskScheduler {
             return false;
         }
     }
-
-    private static class TaskTransaction extends GraphTransaction {
-
-        public static final String TASK = P.TASK;
-
-        public TaskTransaction(HugeGraphParams graph, BackendStore store) {
-            super(graph, store);
-            this.autoCommit(true);
-        }
-
-        public HugeVertex constructVertex(HugeTask<?> task) {
-            if (!this.graph().existsVertexLabel(TASK)) {
-                throw new HugeException("Schema is missing for task(%s) '%s'",
-                                        task.id(), task.name());
-            }
-            return this.constructVertex(false, task.asArray());
-        }
-
-        public void deleteIndex(HugeVertex vertex) {
-            // Delete the old record if exist
-            Iterator<Vertex> old = this.queryVertices(vertex.id());
-            HugeVertex oldV = (HugeVertex) QueryResults.one(old);
-            if (oldV == null) {
-                return;
-            }
-            this.deleteIndexIfNeeded(oldV, vertex);
-        }
-
-        private boolean deleteIndexIfNeeded(HugeVertex oldV, HugeVertex newV) {
-            if (!oldV.value(P.STATUS).equals(newV.value(P.STATUS))) {
-                // Only delete vertex if index value changed else override it
-                this.updateIndex(this.indexLabel(P.STATUS).id(), oldV, true);
-                return true;
-            }
-            return false;
-        }
-
-        public void initSchema() {
-            if (this.existVertexLabel(TASK)) {
-                return;
-            }
-
-            HugeGraph graph = this.graph();
-            String[] properties = this.initProperties();
-
-            // Create vertex label '~task'
-            VertexLabel label = graph.schema().vertexLabel(TASK)
-                                     .properties(properties)
-                                     .useCustomizeNumberId()
-                                     .nullableKeys(P.DESCRIPTION, P.CONTEXT,
-                                                   P.UPDATE, P.INPUT, P.RESULT,
-                                                   P.DEPENDENCIES, P.SERVER)
-                                     .enableLabelIndex(true)
-                                     .build();
-            this.params().schemaTransaction().addVertexLabel(label);
-
-            // Create index
-            this.createIndexLabel(label, P.STATUS);
-        }
-
-        private boolean existVertexLabel(String label) {
-            return this.params().schemaTransaction()
-                       .getVertexLabel(label) != null;
-        }
-
-        private String[] initProperties() {
-            List<String> props = new ArrayList<>();
-
-            props.add(createPropertyKey(P.TYPE));
-            props.add(createPropertyKey(P.NAME));
-            props.add(createPropertyKey(P.CALLABLE));
-            props.add(createPropertyKey(P.DESCRIPTION));
-            props.add(createPropertyKey(P.CONTEXT));
-            props.add(createPropertyKey(P.STATUS, DataType.BYTE));
-            props.add(createPropertyKey(P.PROGRESS, DataType.INT));
-            props.add(createPropertyKey(P.CREATE, DataType.DATE));
-            props.add(createPropertyKey(P.UPDATE, DataType.DATE));
-            props.add(createPropertyKey(P.RETRIES, DataType.INT));
-            props.add(createPropertyKey(P.INPUT, DataType.BLOB));
-            props.add(createPropertyKey(P.RESULT, DataType.BLOB));
-            props.add(createPropertyKey(P.DEPENDENCIES, DataType.LONG,
-                                        Cardinality.SET));
-            props.add(createPropertyKey(P.SERVER));
-
-            return props.toArray(new String[0]);
-        }
-
-        private String createPropertyKey(String name) {
-            return this.createPropertyKey(name, DataType.TEXT);
-        }
-
-        private String createPropertyKey(String name, DataType dataType) {
-            return this.createPropertyKey(name, dataType, Cardinality.SINGLE);
-        }
-
-        private String createPropertyKey(String name, DataType dataType,
-                                         Cardinality cardinality) {
-            HugeGraph graph = this.graph();
-            SchemaManager schema = graph.schema();
-            PropertyKey propertyKey = schema.propertyKey(name)
-                                            .dataType(dataType)
-                                            .cardinality(cardinality)
-                                            .build();
-            this.params().schemaTransaction().addPropertyKey(propertyKey);
-            return name;
-        }
-
-        private IndexLabel createIndexLabel(VertexLabel label, String field) {
-            HugeGraph graph = this.graph();
-            SchemaManager schema = graph.schema();
-            String name = Hidden.hide("task-index-by-" + field);
-            IndexLabel indexLabel = schema.indexLabel(name)
-                                          .on(HugeType.VERTEX_LABEL, TASK)
-                                          .by(field)
-                                          .build();
-            this.params().schemaTransaction().addIndexLabel(label, indexLabel);
-            return indexLabel;
-        }
-
-        private IndexLabel indexLabel(String field) {
-            String name = Hidden.hide("task-index-by-" + field);
-            HugeGraph graph = this.graph();
-            return graph.indexLabel(name);
-        }
-    }
 }
