@@ -42,6 +42,7 @@ import org.apache.hugegraph.backend.store.BackendEntry.BackendColumnIterator;
 import org.apache.hugegraph.backend.store.BackendEntryIterator;
 import org.apache.hugegraph.backend.store.BackendTable;
 import org.apache.hugegraph.backend.store.Shard;
+import org.apache.hugegraph.backend.store.rocksdb.RocksDBSessions.Session;
 import org.apache.hugegraph.exception.NotSupportException;
 import org.apache.hugegraph.iterator.FlatMapperIterator;
 import org.apache.hugegraph.type.HugeType;
@@ -149,6 +150,15 @@ public class RocksDBTable extends BackendTable<RocksDBSessions.Session, BackendE
         return newEntryIterator(this.queryBy(session, query), query);
     }
 
+    @Override
+    public Iterator<BackendEntry> queryOlap(Session session, Query query) {
+        if (query.limit() == 0L && !query.noLimit()) {
+            // LOG.debug("Return empty result(limit=0) for query {}", query);
+            return Collections.emptyIterator();
+        }
+        return newEntryIteratorOlap(this.queryBy(session, query), query, true);
+    }
+
     protected BackendColumnIterator queryBy(RocksDBSessions.Session session, Query query) {
         // Query all
         if (query.empty()) {
@@ -298,6 +308,19 @@ public class RocksDBTable extends BackendTable<RocksDBSessions.Session, BackendE
         });
     }
 
+    protected static BackendEntryIterator newEntryIteratorOlap(
+        BackendColumnIterator cols, Query query, boolean isOlap) {
+        return new BinaryEntryIterator<>(cols, query, (entry, col) -> {
+            if (entry == null || !entry.belongToMe(col)) {
+                HugeType type = query.resultType();
+                // NOTE: only support BinaryBackendEntry currently
+                entry = new BinaryBackendEntry(type, col.name, false, isOlap);
+            }
+            entry.columns(col);
+            return entry;
+        });
+    }
+
     protected static long sizeOfBackendEntry(BackendEntry entry) {
         return BinaryEntryIterator.sizeOfEntry(entry);
     }
