@@ -299,6 +299,9 @@ public class MetricsApiTest extends BaseApiTest {
                     }
                 }
                 break;
+            case "hstore":
+                // TODO(metrics): check metrics info
+                break;
             default:
                 Assert.fail("Unexpected backend " + backend);
                 break;
