@@ -139,6 +139,7 @@ public abstract class CacheTest extends BaseUnitTest {
     public static class OffheapCacheTest extends CacheTest {
 
         private static final long ENTRY_SIZE = 40L;
+        private static final int SEGMENTS = 4;
         private final HugeGraph graph = Mockito.mock(HugeGraph.class);
 
         @Override
@@ -148,7 +149,7 @@ public abstract class CacheTest extends BaseUnitTest {
 
         @Override
         protected Cache<Id, Object> newCache(long capacity) {
-            return new OffheapCache(this.graph(), capacity, ENTRY_SIZE);
+            return new OffheapCache(this.graph(), capacity, ENTRY_SIZE, SEGMENTS);
         }
 
         @Override
@@ -325,7 +326,7 @@ public abstract class CacheTest extends BaseUnitTest {
 
     @Test
     public void testUpdateAndGetWithSameSizeAndCapacity() {
-        int limit = 40;
+        int limit = 1000;
         Cache<Id, Object> cache = newCache(limit);
         Map<Id, Object> map = new LimitMap(limit);
 
@@ -451,7 +452,7 @@ public abstract class CacheTest extends BaseUnitTest {
 
     @Test
     public void testSizeWithReachCapacity() {
-        int limit = 20;
+        int limit = 1000;
         Cache<Id, Object> cache = newCache(limit);
         Map<Id, Object> map = new LimitMap(limit);
 
